# Neets API CLI 
CLI to interact with the [neets.ai](https://neets.ai/) Text To Speech 
and completions API. 


## Configuration

A neets.ai API key must be set as an environment variable. 
```bash
export NEETS_API_KEY=<your api key>
```

## Completions 

Use the `chat` command to generate completions. 

```bash
neets chat --prompt "How soon will I be unemployed?" 
```

By default, the `chat` command will use the `Neets-7B` model.
you can specify a different model with the `--model` flag. 

```bash
neets chat --prompt "why is the sky blue?" --model "mistralai/Mixtral-8X7B-Instruct-v0.1"
```

## Text To Speech

Use the `tts` command to generate audio from text. 

```bash
neets tts --voice "mark-zuckerberg" --text "I'm out here smoking some meats"
```
- To get a list of available voices, use the `voices` command. 
- To specify an output file, use the `--output-file` flag. 
- To specify the output format, use the `--output-fmt`
- The default output file is `[voice]_uuid.[output-fmt]` in the current directory.
- The default output format is `wav` 